SKILL API
=========

A standard library of SKILL and SKILL++ modules.  They are included directly 
in the package Import table for convenience.

Cadence Reference Manuals
--------------------------

Available on Cadence online support:

- `Language Manuals <https://support.cadence.com/apex/Coveo_ProductManuals#t=ProductManualsFromRelease&ph=IC%206.1.8&cadrelease=ic618&seetocfiles=true>`_
- `Language Reference <https://support.cadence.com/apex/techpubDocViewerPage?path=sklangref/sklangrefIC6.1.8/sklangrefTOC.html>`_
- `Language User Guide <https://support.cadence.com/apex/techpubDocViewerPage?path=sklanguser/sklanguserIC6.1.8/sklanguserTOC.html>`_
- `Development Reference <https://support.cadence.com/apex/techpubDocViewerPage?path=skdevref/skdevrefIC6.1.8/skdevrefTOC.html>`_
- `IDE User Guide <https://support.cadence.com/apex/techpubDocViewerPage?path=skillide/skillideIC6.1.8/skillideTOC.html>`_


.. toctree::
   :maxdepth: 2
   :caption: Modules:
   :hidden:

   List
   Str
   Geo.rst
